@@ -26,6 +26,7 @@
 
 #include <KLocalizedString>
 
+#include <algorithm>
 #include <sys/utsname.h>
 
 #ifdef Q_OS_FREEBSD
@@ -69,13 +70,13 @@ void BacklightHelper::initUsingBacklightType()
     backlightDir.setFilter(QDir::AllDirs | QDir::NoDot | QDir::NoDotDot | QDir::NoDotAndDotDot | QDir::Readable);
     backlightDir.setSorting(QDir::Name | QDir::Reversed);// Reverse is needed to priorize acpi_video1 over 0
 
-    QStringList interfaces = backlightDir.entryList();
+    const QStringList interfaces = backlightDir.entryList();
 
     QFile file;
     QByteArray buffer;
     QStringList firmware, platform, raw, leds;
 
-    Q_FOREACH(const QString & interface, interfaces) {
+    for (const QString & interface : interfaces) {
         file.setFileName(BACKLIGHT_SYSFS_PATH + interface + "/type");
         if (!file.open(QIODevice::ReadOnly | QIODevice::Text)) {
             continue;
@@ -173,7 +174,7 @@ void BacklightHelper::initUsingSysctl()
     }
     free(levels);
     // Sorting helps when finding max value and when scanning for the nearest level in setbrightness().
-    qSort(m_sysctlBrightnessLevels.begin(), m_sysctlBrightnessLevels.end());
+    std::sort(m_sysctlBrightnessLevels.begin(), m_sysctlBrightnessLevels.end());
 #endif
 }
 
