@@ -38,9 +38,7 @@
 #include <KAuthAction>
 #include <KIdleTime>
 #include <KLocalizedString>
-#include <KMessageBox>
 #include <KNotification>
-#include <KServiceTypeTrader>
 
 #include <KActivities/Consumer>
 
@@ -129,7 +127,8 @@ void Core::onBackendReady()
                 this, SLOT(onDeviceRemoved(QString)));
 
         // Force the addition of already existent batteries
-        Q_FOREACH (const Device &device, Device::listFromType(DeviceInterface::Battery, QString())) {
+        const auto devices = Device::listFromType(DeviceInterface::Battery, QString());
+        for (const Device &device : devices) {
             onDeviceAdded(device.udi());
         }
     }
@@ -350,7 +349,8 @@ void Core::loadProfile(bool force)
         }
 
         // Cool, now let's load the needed actions
-        Q_FOREACH (const QString &actionName, config.groupList()) {
+        const auto groupList = config.groupList();
+        for (const QString &actionName : groupList) {
             Action *action = ActionPool::instance()->loadAction(actionName, config.group(actionName), this);
             if (action) {
                 action->onProfileLoad();
@@ -479,17 +479,6 @@ void Core::onDeviceRemoved(const QString &udi)
     m_batteriesCharged.remove(udi);
 }
 
-void Core::emitNotification(const QString &evid, const QString &message, const QString &iconname)
-{
-    if (!iconname.isEmpty()) {
-      KNotification::event(evid, message, QIcon::fromTheme(iconname).pixmap(48,48),
-                           nullptr, KNotification::CloseOnTimeout, QStringLiteral("powerdevil"));
-    } else {
-      KNotification::event(evid, message, QPixmap(),
-                           nullptr, KNotification::CloseOnTimeout, QStringLiteral("powerdevil"));
-    }
-}
-
 void Core::emitNotification(const QString &eventId, const QString &title, const QString &message, const QString &iconName)
 {
     KNotification::event(eventId, title, message, iconName, nullptr, KNotification::CloseOnTimeout, QStringLiteral("powerdevil"));
@@ -510,7 +499,12 @@ bool Core::emitBatteryChargePercentNotification(int currentPercent, int previous
     if (b && !b->isPowerSupply()) {
         // if you leave the device out of reach or it has not been initialized yet
         // it won't be "there" and report 0%, don't show anything in this case
-        if (!b->isPresent() || b->chargeState() != Battery::Discharging) {
+        if (!b->isPresent() || b->chargePercent() == 0) {
+            return false;
+        }
+
+        // Bluetooth devices don't report charge state, so it's "NoCharge" in all cases for them
+        if (b->chargeState() != Battery::Discharging && b->chargeState() != Battery::NoCharge) {
             return false;
         }
 
@@ -541,6 +535,13 @@ bool Core::emitBatteryChargePercentNotification(int currentPercent, int previous
                             "Please recharge or replace the battery.", name);
                 icon = QStringLiteral("input-keyboard");
                 break;
+            case Battery::BluetoothBattery:
+                title = i18n("Bluetooth Device Battery Low (%1% Remaining)", currentPercent);
+                msg = i18nc("Placeholder is device name",
+                            "The battery in Bluetooth device \"%1\" is running low, and the device may turn off at any time. "
+                            "Please recharge or replace the battery.", name);
+                icon = QStringLiteral("preferences-system-bluetooth");
+                break;
             default:
                 title = i18nc("The battery in an external device", "Device Battery Low (%1% Remaining)", currentPercent);
                 msg = i18nc("Placeholder is device name",
@@ -797,9 +798,9 @@ void Core::registerActionTimeout(Action* action, int timeout)
 void Core::unregisterActionTimeouts(Action* action)
 {
     // Clear all timeouts from the action
-    QList< int > timeoutsToClean = m_registeredActionTimeouts[action];
+    const QList< int > timeoutsToClean = m_registeredActionTimeouts[action];
 
-    Q_FOREACH (int id, timeoutsToClean) {
+    for (int id : timeoutsToClean) {
         KIdleTime::instance()->removeIdleTimeout(id);
     }
 
